@@ -1,7 +1,7 @@
 #' Lethal time data for seasonal exposure to TFM for larval sea lamprey
 #'
 #' This dataset contains the amount of responding/dead lamprey from 1 to 12 h of exposure to the piscicide, 3-trifluoromethyl-4-nitrophenol (TFM), for the calculated LC50s at each month for the 2011 seasonal larval sea lamprey TFM toxicity data.
-#' @usage lampreytime
+#' @usage lamprey_time
 #' @format A tibble containing 44 rows and 7 columns.
 #' \describe{
 #'   \item{nominal.dose}{nominal TFM dose(mg/L)}
@@ -16,4 +16,4 @@
 #' @source Hlina, B.L., Birceanu, O., Robinson, C.S., Thackeray, N., Tessier, L.R., Muhametsafina, A., Bragg, L.M., Servos, M.R., Wilkie, M.P. *In Preparation*. Changes in the sensitivity of piscicide in an invasive species. Environmental Science & Technology.
 
 
-"lampreytime"
+"lamprey_time"
